@@ -532,7 +532,7 @@ See http://dev.perl.org/licenses/ for more information.
 
 package Config::MyConfig2;
 
-our $VERSION = 2.19;
+our $VERSION = 2.20;
 
 use strict;
 use Carp;
@@ -561,6 +561,9 @@ sub ReadConfig
 {
 	my $self = shift;
 	
+	# Clean config, just in case this method is called more than once
+	$self->{config} = undef;
+	
 	$self->error("Configuration File not specified!") if (! $self->{opts}->{conffile});
     $self->error("Couldn't read configuration file $self->{opts}->{conffile}!") if (! -r $self->{opts}->{conffile});
 	
@@ -653,7 +656,7 @@ sub _ConfigDirective
 					# Do all values match the configured conditions (match)?
 					if ($_ !~ $self->{Directives}->{$directive_name}->{$key}->{match})
 					{
-						$line = -1 ? return "Syntax error (value): $keyword -> $value" : $self->error("Syntax error (value) in configfile line $line: $keyword     near $_");
+						$line == -1 ? return "Syntax error (value): $keyword -> $value" : $self->error("Syntax error (value) in configfile line $line: $keyword     near $_");
 					}						
 				}
 			# Keyword a single keyword?
@@ -662,7 +665,7 @@ sub _ConfigDirective
 				# Does the value matches the configured condition (match)?
 				if ($value !~$self->{Directives}->{$directive_name}->{$key}->{match})
 				{
-					$line = -1 ? return "Syntax error (value): $keyword -> $value" : $self->error("Syntax error (value) in configfile line $line: $keyword     $value");
+					$line == -1 ? return "Syntax error (value): $keyword -> $value" : $self->error("Syntax error (value) in configfile line $line: $keyword     $value");
 				}
 			}
 			
@@ -698,7 +701,7 @@ sub _ConfigDirective
 	# If the keyword hasn't been found in the list of all configured keywords, it's an error in the configuration file
 	if (!$foundflag)
 	{
-		$line = -1 ? return "Syntax error (keyword): $keyword -> $value" : $self->error("Syntax error (keyword) in configfile line $line: $keyword     $value")
+		$line == -1 ? return "Syntax error (keyword): $keyword -> $value" : $self->error("Syntax error (keyword) in configfile line $line: $keyword     $value")
 	}
 	
 }
